@@ -1,12 +1,13 @@
 import param as _param
 
-from . import geometry, spatialindex, tools  # noqa
-from .geodataframe import GeoDataFrame  # noqa
-from .geoseries import GeoSeries  # noqa
-from .tools.sjoin import sjoin  # noqa
+from . import geometry, spatialindex, tools
+from .geodataframe import GeoDataFrame
+from .geoseries import GeoSeries
+from .tools.sjoin import sjoin
 
 try:
     import dask.dataframe  # noqa
+
     # Import to trigger registration of types with Dask
     import spatialpandas.dask  # noqa
 except ImportError:
@@ -19,3 +20,12 @@ __version__ = str(
         archive_commit="$Format:%h$",
         reponame="spatialpandas",
     ))
+
+__all__ = [
+    "GeoDataFrame",
+    "GeoSeries",
+    "geometry",
+    "sjoin",
+    "spatialindex",
+    "tools",
+]
