@@ -83,11 +83,11 @@ class DaskGeoSeries(dd.Series):
     def cx_partitions(self):
         return _DaskPartitionCoordinateIndexer(self, self.partition_sindex)
 
-    def build_sindex(self):
-        def build_sindex(series):
-            series.build_sindex()
+    def build_sindex(self, **kwargs):
+        def build_sindex(series, **kwargs):
+            series.build_sindex(**kwargs)
             return series
-        return self.map_partitions(build_sindex, meta=self._meta)
+        return self.map_partitions(build_sindex, **kwargs, meta=self._meta)
 
     def intersects_bounds(self, bounds):
         return self.map_partitions(lambda s: s.intersects_bounds(bounds))
@@ -200,8 +200,17 @@ class DaskGeoDataFrame(dd.DataFrame):
         return ddf
 
     def pack_partitions_to_parquet(
-            self, path, filesystem=None, npartitions=None, p=15, compression="snappy",
-            tempdir_format=None, _retry_args=None
+        self,
+        path,
+        filesystem=None,
+        npartitions=None,
+        p=15,
+        compression="snappy",
+        tempdir_format=None,
+        _retry_args=None,
+        storage_options=None,
+        engine_kwargs=None,
+        overwrite=False,
     ):
         """
         Repartition and reorder dataframe spatially along a Hilbert space filling curve
@@ -228,21 +237,25 @@ class DaskGeoDataFrame(dd.DataFrame):
 
                 These directories are deleted as soon as possible during the execution
                 of the function.
+            storage_options: Key/value pairs to be passed on to the file-system backend, if any.
+            engine_kwargs: pyarrow.parquet engine-related keyword arguments.
         Returns:
             DaskGeoDataFrame backed by newly written parquet dataset
         """
         from .io import read_parquet, read_parquet_dask
         from .io.utils import validate_coerce_filesystem
 
+        engine_kwargs = engine_kwargs or {}
+
         # Get fsspec filesystem object
-        filesystem = validate_coerce_filesystem(path, filesystem)
+        filesystem = validate_coerce_filesystem(path, filesystem, storage_options)
 
         # Decorator for operations that should be retried
         if _retry_args is None:
             _retry_args = dict(
                 wait_exponential_multiplier=100,
                 wait_exponential_max=120000,
-                stop_max_attempt_number=24
+                stop_max_attempt_number=24,
             )
         retryit = retry(**_retry_args)
 
@@ -320,7 +333,8 @@ class DaskGeoDataFrame(dd.DataFrame):
 
         # Initialize output partition directory structure
         filesystem.invalidate_cache()
-        rm_retry(path)
+        if overwrite:
+            rm_retry(path)
 
         for out_partition in out_partitions:
             part_dir = os.path.join(path, "part.%d.parquet" % out_partition)
@@ -332,17 +346,25 @@ class DaskGeoDataFrame(dd.DataFrame):
         @retryit
         def write_partition(df_part, part_path):
             with filesystem.open(part_path, "wb") as f:
-                df_part.to_parquet(f, compression=compression, index=True)
+                df_part.to_parquet(
+                    f,
+                    compression=compression,
+                    index=True,
+                    **engine_kwargs,
+                )
+
 
         def process_partition(df, i):
             subpart_paths = {}
             for out_partition, df_part in df.groupby('_partition'):
                 part_path = os.path.join(
                     tempdir_format.format(partition=out_partition, uuid=dataset_uuid),
-                    'part.%d.parquet' % i
+                    'part.%d.parquet' % i,
                 )
-                df_part = df_part.drop('_partition', axis=1).set_index(
-                    'hilbert_distance', drop=True
+                df_part = (
+                    df_part
+                    .drop('_partition', axis=1)
+                    .set_index('hilbert_distance', drop=True)
                 )
                 write_partition(df_part, part_path)
                 subpart_paths[out_partition] = part_path
@@ -377,7 +399,12 @@ class DaskGeoDataFrame(dd.DataFrame):
                 # Handle rare case where the task was resubmitted and the work has
                 # already been done.  This shouldn't happen with pure=False, but it
                 # seems like it does very rarely.
-                return read_parquet(part_output_path, filesystem=filesystem)
+                return read_parquet(
+                    part_output_path,
+                    filesystem=filesystem,
+                    storage_options=storage_options,
+                    **engine_kwargs,
+                )
 
             ls_res = sorted(filesystem.ls(parts_tmp_path, **ls_kwargs))
             subpart_paths_stripped = sorted([filesystem._strip_protocol(_) for _ in subpart_paths])
@@ -397,7 +424,12 @@ class DaskGeoDataFrame(dd.DataFrame):
                         extras=list(extras)
                     )
                 )
-            return read_parquet(parts_tmp_path, filesystem=filesystem)
+            return read_parquet(
+                parts_tmp_path,
+                filesystem=filesystem,
+                storage_options=storage_options,
+                **engine_kwargs,
+            )
 
         def concat_parts(parts_tmp_path, subpart_paths, part_output_path):
             filesystem.invalidate_cache()
@@ -495,7 +527,12 @@ class DaskGeoDataFrame(dd.DataFrame):
                 pq.write_metadata(new_schema, f)
         write_commonmetadata_file()
 
-        return read_parquet_dask(path, filesystem=filesystem)
+        return read_parquet_dask(
+            path,
+            filesystem=filesystem,
+            storage_options=storage_options,
+            engine_kwargs=engine_kwargs,
+        )
 
     def _compute_packing_npartitions(self, npartitions):
         if npartitions is None:
@@ -528,11 +565,11 @@ class DaskGeoDataFrame(dd.DataFrame):
             new_series._partition_sindex = self._partition_sindex[new_series.name]
         return new_series
 
-    def build_sindex(self):
-        def build_sindex(df):
-            df.build_sindex()
+    def build_sindex(self, **kwargs):
+        def build_sindex(df, **kwargs):
+            df.build_sindex(**kwargs)
             return df
-        return self.map_partitions(build_sindex, meta=self._meta)
+        return self.map_partitions(build_sindex, **kwargs, meta=self._meta)
 
     def persist(self, **kwargs):
         return self._propagate_props_to_dataframe(
